package com.menagerie.themeswitcher

import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.material3.Button
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.*
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.booleanPreferencesKey
import androidx.datastore.preferences.core.byteArrayPreferencesKey
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import org.jetbrains.compose.ui.tooling.preview.Preview
import com.menagerie.themeswitcher.ui.theme.*
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch

enum class Theme {
    Auto,
    Light,
    Dark
}

val themeKey = stringPreferencesKey("theme")


@Composable
@Preview
fun App(
    prefs: DataStore<Preferences>
) {

    val currentThemeString by prefs
            .data
            .map {
                it[themeKey] ?: Theme.Dark.name
            }
            .collectAsState(Theme.Dark.name)

    var currentTheme = Theme.valueOf(currentThemeString)

    val scope = rememberCoroutineScope()
    val isDarkTheme: Boolean? = when (currentTheme) {
        Theme.Dark -> true
        Theme.Light -> false
        Theme.Auto -> null
    }

    val onThemeToggle = {
        currentTheme = when (currentTheme) {
            Theme.Auto -> Theme.Light
            Theme.Light -> Theme.Dark
            Theme.Dark -> Theme.Auto
        }
    }
    MainTheme(isDarkTheme ?: isSystemInDarkTheme()) {
        Scaffold {
            Column(Modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally) {
                Button(onClick = {
                    scope.launch {
                        onThemeToggle.invoke()
                        prefs.edit {
                            it[themeKey] = currentTheme.name
                        }
                    }
                }) {
                    val text: String = currentTheme.name
                    Text(text)
                }
            }
        }
    }
}